@@ -218,6 +218,9 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetSentPaymentsForSqueak(self, request, context):
         return self.handler.handle_get_sent_payments_for_squeak(request)
 
+    def GetSentPaymentsForPubkey(self, request, context):
+        return self.handler.handle_get_sent_payments_for_pubkey(request)
+
     def GetSentPayment(self, request, context):
         return self.handler.handle_get_sent_payment(request)
 
@@ -230,6 +233,9 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetReceivedPaymentsForSqueak(self, request, context):
         return self.handler.handle_get_received_payments_for_squeak(request)
 
+    def GetReceivedPaymentsForPubkey(self, request, context):
+        return self.handler.handle_get_received_payments_for_pubkey(request)
+
     def SubscribeReceivedPayments(self, request, context):
         stopped = threading.Event()
 
@@ -249,7 +255,7 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
         return self.handler.handle_get_payment_summary(request)
 
     def GetPaymentSummaryForSqueak(self, request, context):
-        return self.handler.handle_get_payment_summary_(request)
+        return self.handler.handle_get_payment_summary_for_squeak(request)
 
     def ReprocessReceivedPayments(self, request, context):
         return self.handler.handle_reprocess_received_payments(request)
