@@ -62,9 +62,17 @@ class SqueakCore:
         self.bitcoin_client = bitcoin_client
         self.lightning_client = lightning_client
 
-    def make_squeak(self, signing_profile: SqueakProfile, content_str: str, replyto_hash: Optional[bytes] = None) -> Tuple[CSqueak, bytes]:
+    def make_squeak(
+            self,
+            signing_profile: SqueakProfile,
+            content_str: str,
+            replyto_hash: Optional[bytes] = None,
+            recipient_profile: Optional[SqueakProfile] = None,
+    ) -> Tuple[CSqueak, bytes]:
         """Create a new squeak.
 
+        TODO: Include the block header in the result tuple.
+
         Args:
             signing_profile: The profile of the author of the squeak.
             content_str: The content of the squeak as a string.
@@ -82,13 +90,15 @@ class SqueakCore:
         block_info = self.bitcoin_client.get_best_block_info()
         block_height = block_info.block_height
         block_hash = block_info.block_hash
-        return make_squeak_with_block(
+        squeak, secret_key = make_squeak_with_block(
             signing_profile.private_key,
             content_str,
             block_height,
             block_hash,
-            replyto_hash,
+            replyto_hash=replyto_hash,
+            recipient_public_key=recipient_profile.public_key if recipient_profile else None,
         )
+        return squeak, secret_key
 
     def check_squeak(self, squeak: CSqueak) -> None:
         """Checks if the squeak is valid and has a valid signature.
@@ -123,21 +133,38 @@ class SqueakCore:
             raise Exception("Block hash incorrect.")
         return block_info.block_header
 
-    def get_decrypted_content(self, squeak: CSqueak, secret_key: bytes) -> str:
+    def get_decrypted_content(
+            self,
+            squeak: CSqueak,
+            secret_key: bytes,
+            author_profile: Optional[SqueakProfile] = None,
+            recipient_profile: Optional[SqueakProfile] = None,
+    ) -> str:
         """Checks if the secret key is valid for the given squeak and returns
         the decrypted content.
 
         Args:
             squeak: The squeak to be validated.
             secret_key: The secret key.
+            author_profile: The profile of the author.
+            recipient_profile: The profile of the recipient.
 
         Returns:
-            bytes: the decrypted content
+            str: the decrypted content as a string.
 
         Raises:
             Exception: If the secret key is not valid.
         """
-        return get_decrypted_content(squeak, secret_key)
+        if author_profile and author_profile.private_key is None:
+            raise Exception("Author profile does not have private key.")
+        if recipient_profile and recipient_profile.private_key is None:
+            raise Exception("Recipient profile does not have private key.")
+        return get_decrypted_content(
+            squeak,
+            secret_key,
+            authorPrivKey=author_profile.private_key if author_profile else None,
+            recipientPrivKey=recipient_profile.private_key if recipient_profile else None,
+        )
 
     def get_best_block_height(self) -> int:
         """Get the current height of the latest block in the blockchain.
@@ -361,15 +388,16 @@ class SqueakCore:
                         payment_hash = invoice.r_hash
                         settle_index = invoice.settle_index
                         sent_offer = get_sent_offer_fn(payment_hash)
-                        yield ReceivedPayment(
-                            received_payment_id=None,
-                            created_time_ms=None,
-                            squeak_hash=sent_offer.squeak_hash,
-                            payment_hash=sent_offer.payment_hash,
-                            price_msat=sent_offer.price_msat,
-                            settle_index=settle_index,
-                            peer_address=sent_offer.peer_address,
-                        )
+                        if sent_offer is not None:
+                            yield ReceivedPayment(
+                                received_payment_id=None,
+                                created_time_ms=None,
+                                squeak_hash=sent_offer.squeak_hash,
+                                payment_hash=sent_offer.payment_hash,
+                                price_msat=sent_offer.price_msat,
+                                settle_index=settle_index,
+                                peer_address=sent_offer.peer_address,
+                            )
             except grpc.RpcError as e:
                 if e.code() != grpc.StatusCode.CANCELLED:
                     raise InvoiceSubscriptionError()
