@@ -418,6 +418,18 @@ class SqueakStore:
             last_sent_payment,
         )
 
+    def get_sent_payments_for_pubkey(
+            self,
+            pubkey: SqueakPublicKey,
+            limit: int,
+            last_sent_payment: Optional[SentPayment],
+    ) -> List[SentPayment]:
+        return self.squeak_db.get_sent_payments_for_pubkey(
+            pubkey,
+            limit,
+            last_sent_payment,
+        )
+
     def get_sent_payment(self, sent_payment_id: int) -> Optional[SentPayment]:
         return self.squeak_db.get_sent_payment(sent_payment_id)
 
@@ -449,6 +461,18 @@ class SqueakStore:
             last_received_payment,
         )
 
+    def get_received_payments_for_pubkey(
+            self,
+            pubkey: SqueakPublicKey,
+            limit: int,
+            last_received_payment: Optional[ReceivedPayment],
+    ) -> List[ReceivedPayment]:
+        return self.squeak_db.get_received_payments_for_pubkey(
+            pubkey,
+            limit,
+            last_received_payment,
+        )
+
     def delete_all_expired_offers(self):
         self.delete_all_expired_received_offers()
         self.delete_all_expired_sent_offers()
@@ -561,15 +585,21 @@ class SqueakStore:
     def get_received_payment_summary(self) -> ReceivedPaymentSummary:
         return self.squeak_db.get_received_payment_summary()
 
-    def get_sent_payment_summary(self) -> SentPaymentSummary:
-        return self.squeak_db.get_sent_payment_summary()
-
     def get_received_payment_summary_for_squeak(self, squeak_hash: bytes) -> ReceivedPaymentSummary:
         return self.squeak_db.get_received_payment_summary_for_squeak(squeak_hash)
 
+    def get_received_payment_summary_for_pubkey(self, pubkey: SqueakPublicKey) -> ReceivedPaymentSummary:
+        return self.squeak_db.get_received_payment_summary_for_pubkey(pubkey)
+
+    def get_sent_payment_summary(self) -> SentPaymentSummary:
+        return self.squeak_db.get_sent_payment_summary()
+
     def get_sent_payment_summary_for_squeak(self, squeak_hash: bytes) -> SentPaymentSummary:
         return self.squeak_db.get_sent_payment_summary_for_squeak(squeak_hash)
 
+    def get_sent_payment_summary_for_pubkey(self, pubkey: SqueakPublicKey) -> SentPaymentSummary:
+        return self.squeak_db.get_sent_payment_summary_for_pubkey(pubkey)
+
     def clear_received_payment_settle_indices(self) -> None:
         self.squeak_db.clear_received_payment_settle_indices()
 
